summaryrefslogtreecommitdiffstats
path: root/noatun-plugins/oblique/tree.h
diff options
context:
space:
mode:
Diffstat (limited to 'noatun-plugins/oblique/tree.h')
-rw-r--r--noatun-plugins/oblique/tree.h25
1 files changed, 13 insertions, 12 deletions
diff --git a/noatun-plugins/oblique/tree.h b/noatun-plugins/oblique/tree.h
index f059931..8f92f2a 100644
--- a/noatun-plugins/oblique/tree.h
+++ b/noatun-plugins/oblique/tree.h
@@ -23,15 +23,15 @@ class TreeItem : public KListViewItem
bool mHidden:1;
public:
- TreeItem(Tree *parent, QueryGroup *group, const File &file, const TQString &p=0);
- TreeItem(TreeItem *parent, QueryGroup *group, const File &file, const TQString &p=0);
+ TreeItem(Tree *tqparent, QueryGroup *group, const File &file, const TQString &p=0);
+ TreeItem(TreeItem *tqparent, QueryGroup *group, const File &file, const TQString &p=0);
~TreeItem();
QueryGroup *group() { return mGroup; }
const QueryGroup *group() const { return mGroup; }
void setGroup(QueryGroup *group) { mGroup = group; }
- TreeItem *parent() { return static_cast<TreeItem*>(KListViewItem::parent()); }
+ TreeItem *tqparent() { return static_cast<TreeItem*>(KListViewItem::tqparent()); }
Tree *tree();
TreeItem *itemBelow() { return static_cast<TreeItem*>(KListViewItem::itemBelow()); }
TreeItem *firstChild() { return static_cast<TreeItem*>(KListViewItem::firstChild()); }
@@ -45,13 +45,13 @@ public:
void setOpen(bool o);
- TreeItem *find(File item);
+ TreeItem *tqfind(File item);
bool playable() const;
/**
* get the next item that is playable logically.
* that is, if it has a File, and its parent hasn't a
* File
**/
TreeItem *nextPlayable();
@@ -61,8 +61,8 @@ public:
virtual int compare(TQListViewItem * i, int col, bool) const;
/**
- * open my parents so that I'm visible, if I'm playing or
- * close my parents if I'm not playing, and the user
+ * open my tqparents so that I'm visible, if I'm playing or
+ * close my tqparents if I'm not playing, and the user
* didn't open
**/
void autoExpand();
@@ -86,6 +86,7 @@ class Loader;
class Tree : public KListView
{
Q_OBJECT
+ TQ_OBJECT
Oblique *mOblique;
Query mQuery;
@@ -103,10 +104,10 @@ Q_OBJECT
Loader *mLoader;
public:
- Tree(Oblique *oblique, TQWidget *parent=0);
+ Tree(Oblique *oblique, TQWidget *tqparent=0);
~Tree();
TreeItem *firstChild();
- TreeItem *find(File item);
+ TreeItem *tqfind(File item);
TreeItem *current() { return mCurrent; }
Query *query() { return &mQuery; }
Oblique *oblique() { return mOblique; }
@@ -129,10 +130,10 @@ public:
protected:
virtual TQDragObject *dragObject();
- void movableDropEvent(TQListViewItem* parent, TQListViewItem* afterme);
+ void movableDropEvent(TQListViewItem* tqparent, TQListViewItem* afterme);
public slots:
- void insert(TreeItem *replace, File file);
+ void insert(TreeItem *tqreplace, File file);
void insert(File file);
void remove(File file);
void update(File file);
@@ -181,7 +182,7 @@ private:
TreeItem *node(TreeItem *fix, QueryGroup *group, const File &file, TreeItem *childOf);
/**
- * remove the siblings and children of the treeitem
+ * remove the siblings and tqchildren of the treeitem
**/
void remove(TreeItem *, const File &file);
@@ -45,13 +45,13 @@ public:
/**
* get the next item that is playable logically.
- * that is, if it has a File, and its parent hasn't a
+ * that is, if it has a File, and its tqparent hasn't a
* File
**/